from genericpath import exists
from re import U
import sys, os
import os.path
from os import path
from os.path import exists
import shutil
from exceptions import *
from config import *
from pathlib import Path


class AutomaticFolderCreation(object):
    # This variable is made globally as so it can be used by the creatingFolders function
    global variable_list
    variable_list =[]

    def __init__(self, full_dictionary):
        self.full_dictionary = full_dictionary
    
    # This function is used to store variable of the directory we will be sorting at, recieved from the determine_location.py module
    # Used and stored here and kept at runtime
    def variable_holder(self, variable):
        try:
            self.user_location=variable
            variable_list.append(self.user_location)
            print(variable_list)
        except Exception:
            print('---Something is not right ---')

    #This function creates the folder based on the mame given at self.full_dictionary 
    # it does so by doing some string manipulations
    def creatingFolders(self):
        here=variable_list[0]
        os.chdir(here)
        created_folders = []
        try:
            for ending in self.full_dictionary:
                
                folder_name = ending
                
                if '.' in folder_name:
                    
                    folder_name=folder_name.replace(".", "")
                    
                
                
                if ending == 'other':
                    self.MoveFoldersIntoFolders(folder_name)

                if exists(folder_name):
                    print(folder_name, " already exists, skipping")
                    self.MoveFilesIntofolder(folder_name)
                else:
                    os.mkdir(folder_name)
                    self.MoveFilesIntofolder(folder_name)
                    
                created_folders.append(folder_name)

        except Exception:
            print('couldnt create folder')
            
    # This function deals with moving of files into folders

    def MoveFilesIntofolder(self, foldername):
        self.foldername=foldername
        orig_name="."+self.foldername
        file_to_move_list=self.full_dictionary.get(orig_name)

        try:
            if file_to_move_list is  not None:
                for file in file_to_move_list:
                    if os.path.exists(foldername+"/"+file) == False:
                        shutil.move(file, foldername)
                        
                    else:
                        print(file, 'is already present in ', foldername)
            else:
                print("The list of files is a nonetype hence mostly, the extension has no \
                        extensions needing it at the moment")
        except Exception:
            print('file will not move')

    # This will move folders into folders, normally based on the other 
    
    
    def MoveFoldersIntoFolders(self, folder_name):
        try:    
            if os.path.exists('other')== False:
                os.mkdir('other')
            file_to_move_list=self.full_dictionary.get(folder_name)
            if file_to_move_list is not None:
                for file in file_to_move_list:
                    if os.path.exists(folder_name+"/"+file) == False:
                        shutil.move(file, "other")
                    else:
                        print(file, " already exists within", folder_name)
        except Exception:
            print('File did not move')


# import pathlib
# from setuptools import find_packages, setup, find_namespace_packages


# here = pathlib.Path(__file__).parent.resolve()
# install_requires = (here / 'requirements.txt').read_text(encoding='utf-8').splitlines()

# VERSION='0.0.12'
# DESCRIPTION = 'Auto sorting tool to allow you organise any file or folder in a directory using the file extensions'

# with open("README.md", "r") as fh:
#     long_description=fh.read()

# setup(
#     #name="sortmyfolder",
#     version=VERSION,
#     description=DESCRIPTION,
#     #package_dir={'':'auto_group'},
#     long_description=long_description,
#     long_description_content_type="text/markdown",
#     packages=find_namespace_packages(
#         where=['auto_group', 'auto_group.*']
#     ),
#     include_package_data=True,
#     install_requires=install_requires,
#     keywords=['python', 'automation', 'sorting'],
#     classifiers=[
#         "Development Status :: 1 - Planning",
#         "Intended Audience :: Developers",
#         "Operating System :: Unix",
#         "Operating System :: MacOS :: MacOS X",
#         "Operating System :: Microsoft :: Windows",
#     ],
#     entry_points={
#         'console_scripts': [
#             'sortmyfolder=auto_group.determine_location:main',
#         ],
#     },
# )


from setuptools import setup, find_packages
import codecs
import os

here = os.path.abspath(os.path.dirname(__file__))

with codecs.open(os.path.join(here, "README.md"), encoding="utf-8") as fh:
    long_description = "\n" + fh.read()

VERSION = '0.0.14'
DESCRIPTION = 'folder sorting python code'
LONG_DESCRIPTION = 'A package that allows to build simple streams of video, audio and camera data.'

# Setting up
setup(
    name="sortmyfolder",
    version=VERSION,
    description=DESCRIPTION,
    long_description_content_type="text/markdown",
    long_description=long_description,
    packages=find_packages('auto`-group'),
    install_requires=['opencv-python', 'pyautogui', 'pyaudio', "shutil"],
    keywords=['python', 'video', 'stream', 'video stream', 'camera stream', 'sockets'],
    classifiers=[
        "Development Status :: 1 - Planning",
        "Intended Audience :: Developers",
        "Programming Language :: Python :: 3",
        "Operating System :: Unix",
        "Operating System :: MacOS :: MacOS X",
        "Operating System :: Microsoft :: Windows",
    ]
)


import os
import sys
import winreg as reg

cwd = os.getcwd()

python_exe = sys.executable

key_path = r"Directory\\Background\\shell\\Organiser"

key = reg.CreateKeyEx(reg.HKEY_CLASSES_ROOT, key_path)

reg.setValue(key, '', reg.REG_SZ, '&Organise folder')

key1 = reg.CreateKeyEc(key, r"commad")


reg.SetValue(key1, reg.REG_SZ, python_exe +f'"{cwd}\\file_organiser.py"')






import sys, getopt
from os import execv, path
from tabnanny import check
from exceptions import *
import gather_files
import default_folders


class WhereToSortFiles(object):
    
    def location_of_folder_creation(self,  location):
        user_location=location[0]
        #Simple input questions for user to answer
        location_question = input('do you want to organise folders in your current location, which is {}: yes or no:--> ' .format(user_location))
        try:
            if location_question.lower() == 'no':
                while True:
                    try:
                        user_location = input('where do you want the files saved? eg /Users/ :--> ')
                        if not path.exists(user_location):
                            print('the path you entered does not exist')

                            raise PathDoesNotExist
                        else:
                            user_location=user_location
                            something ={"test_variable":"ValueHere"}
                            #Sends the location/directory of where sorting will occur to the defualt_folders.py module to be stored there and used
                            #Runtime and to be kept there-

                            default_folders.AutomaticFolderCreation(something).variable_holder(user_location)

                            #Sends information to the gather_files.py module where it will determine what type of files are stationed in direction
                            f = gather_files
                            b=f.ListingGivenDirectory(user_location)
                            b.files_in_path()
                            break
                    except Exception:
                        print('the specifid path does not exit')

            elif location_question.lower() == 'yes':
                #determining what location file is at
                print('the user_location is', user_location)
                check_user_location = path.exists(user_location)
                if check_user_location:
                    print(check_user_location)
                    #For some strange reason it requires the use of a dictionary as an argument... investigate why?
                    something ={"test_variable":"ValueHere"}
                    default_folders.AutomaticFolderCreation(something).variable_holder(user_location)
                    f = gather_files
                    b=f.ListingGivenDirectory(user_location)
                    b.files_in_path()


            else:
                print('Your answer was neither yes or no :(')
            something ={"test_variable":"ValueHere"}
            default_folders.AutomaticFolderCreation(something).variable_holder(user_location)
        except Exception:
            print('---something is not right ---')
        

# a.location_of_folder_creation("/Users/emmanuelagyapong/Documents/tests_files")


def main(cli_argument):
    WhereToSortFiles().location_of_folder_creation(cli_argument)

if __name__ == '__main__':
   main(sys.argv[1:])